@@ -1,6 +1,8 @@
 #! /usr/bin/env python
 
-import numpy as np
+
+import numpy as np; np.random.seed(0)
+import seaborn as sns; sns.set_theme()
 from matplotlib import pyplot as plt
 import matplotlib
 from numpy import genfromtxt
@@ -53,28 +55,39 @@ class heatMap:
 
 		return H_sorted_kernel
 
-	def draw_HeatMap(self, kernel, xlabel=[], ylabel=[], title='', fsize=14):
-		ylabel = list(reversed(ylabel))
-		
-		kernel = np.flipud(kernel)
-		fig, ax = plt.subplots()
-		#fig.set_size_inches(13,13)
-		heatmap = plt.pcolor(kernel, cmap=matplotlib.cm.Blues, alpha=0.8)
+	def draw_HeatMap(self, kernel, xlabel=[], ylabel=[], title='', fsize=14, use_seaborn=False, vmin=0, vmax=1, center=None, linewidths=0, cmap=None, path=''):
+		if use_seaborn:
+			ax = sns.heatmap(kernel, vmin=vmin, vmax=vmax, center=center, linewidths=linewidths, cmap=cmap)
+			plt.title(title, fontsize=fsize)
+			plt.tight_layout()
+			plt.show() 
+		else:
+			ylabel = list(reversed(ylabel))
+			
+			kernel = np.flipud(kernel)
+			fig, ax = plt.subplots()
+			#fig.set_size_inches(13,13)
+			heatmap = plt.pcolor(kernel, cmap=matplotlib.cm.Blues, alpha=0.8)
+	
+			if len(ylabel) > 0:
+				ax.set_yticks(np.arange(kernel.shape[0]) + 0.5, minor=False)
+				ax.set_yticklabels(ylabel, rotation='horizontal', minor=False, size=fsize)
+			
+			if len(xlabel) > 0:
+				ax.set_xticks(np.arange(kernel.shape[1]) + 0.5, minor=False)
+				ax.set_xticklabels(xlabel, rotation='vertical', minor=False, size=fsize)
+		 
+			plt.title(title, fontsize=fsize)
 
-		if len(ylabel) > 0:
-			ax.set_yticks(np.arange(kernel.shape[0]) + 0.5, minor=False)
-			ax.set_yticklabels(ylabel, rotation='horizontal', minor=False)
-		
-		if len(xlabel) > 0:
-			ax.set_xticks(np.arange(kernel.shape[1]) + 0.5, minor=False)
-			ax.set_xticklabels(xlabel, rotation='vertical', minor=False)
-	 
-		plt.title(title, fontsize=fsize)
-		plt.show() 
+			if path == '':
+				plt.show() 
+			else:
+				plt.draw()	
+				fig.savefig(path, dpi=500)
 
 		return plt
 
-	def save_HeatMap(self, path, kernel, xlabel=[], ylabel=[], title=''):
+	def save_HeatMap(self, path, kernel, xlabel=[], ylabel=[], title='',fsize=14):
 		#xlabel = list(reversed(xlabel))
 		ylabel = list(reversed(ylabel))
 	
@@ -85,13 +98,13 @@ class heatMap:
 
 		if len(ylabel) > 0:
 			ax.set_yticks(np.arange(kernel.shape[0]) + 0.5, minor=False)
-			ax.set_yticklabels(ylabel, rotation='horizontal', minor=False)
+			ax.set_yticklabels(ylabel, rotation='horizontal', minor=False, fsize=fsize)
 		
 		if len(xlabel) > 0:
 			ax.set_xticks(np.arange(kernel.shape[1]) + 0.5, minor=False)
-			ax.set_xticklabels(xlabel, rotation='vertical', minor=False)
+			ax.set_xticklabels(xlabel, rotation='vertical', minor=False, fsize=fsize)
 	 
-		plt.title(title)
+		plt.title(title,fsize=14)
 		plt.draw()	
 		fig.savefig(path, dpi=500)
 		return plt
@@ -116,7 +129,8 @@ if __name__ == "__main__":
 	axis_label = range(kernel.shape[0])
 	hMap = heatMap()
 	sorted_kernel = hMap.sort_kernel(kernel, allocation)
-	#hMap.draw_HeatMap(sorted_kernel, xlabel=axis_label, ylabel=axis_label, title='')
-	hMap.draw_HeatMap(kernel, title='Drawing Unsorted Heat Map')
-	hMap.draw_HeatMap(sorted_kernel, title='Drawing Sorted Heat Map')
 
+	hMap.draw_HeatMap(kernel, title='Drawing Unsorted Heat Map', fsize=14)
+	hMap.draw_HeatMap(sorted_kernel, title='Drawing Sorted Heat Map', fsize=14)
+	hMap.draw_HeatMap(sorted_kernel, title='Drawing Sorted Heat Map', use_seaborn=True, vmin=0, vmax=1, center=None, linewidths=0, cmap=None, fsize=14)
+	#cmap types: "Blues", "YlGnBu", "BuPu", "Greens", None
